import {useEffect, useState} from 'react'
import './Help.css'
import Request from '../Request.jsx'

let init = false
let defaultDownloadUrl = "您的服务器管理员没有可供下载的预打补丁的应用程序包。请参阅下面的问题。"

function Help() {
    const [downloadUrl, setDownloadUrl] = useState(<div>{defaultDownloadUrl}</div>);
    const [downloadUrliOSGL, setDownloadUrliOSGL] = useState("https://ethanthesleepy.one/public/lovelive/sif2/sif2-gl.ipa");
    const [downloadUrliOSJP, setDownloadUrliOSJP] = useState("https://ethanthesleepy.one/public/lovelive/sif2/sif2-jp.ipa");

    const [assetUrl, setAssetUrl] = useState("https://sif2.sif.moe");

    useEffect(() => {
        (async () => {
            if (init) return;
            init = true;
            let resp = await Request("/api/webui/serverInfo");
            if (resp.result !== "OK") {
                return;
            }
            if (!resp.data.links) return;
            if (resp.data.links.global && resp.data.links.japan) {
                setDownloadUrl(
                        <div>您的服务器管理员有下载链接！下载 <a href={resp.data.links.japan}>日服</a> 或者 <a
                                href={resp.data.links.global}>国际服</a></div>
                );
            } else if (resp.data.links.global) {
                setDownloadUrl(
                        <div>您的服务器管理员有下载链接！下载 <a href={resp.data.links.global}>国际服</a></div>
                );
            } else if (resp.data.links.japan) {
                setDownloadUrl(
                        <div>您的服务器管理员有下载链接！下载 <a href={resp.data.links.japan}>日服</a></div>
                );
            }
            if (resp.data.links.assets) {
                setAssetUrl(resp.data.links.assets);
            }

            if (!resp.data.links.ios) return;
            if (resp.data.links.ios.japan) {
                setDownloadUrliOSJP(resp.data.links.ios.japan);
            }
            if (resp.data.links.ios.global) {
                setDownloadUrliOSGL(resp.data.links.ios.global);
            }

        })();
    });

    const renderNoAndroidDownloadUrl = () => {
        return <>
            <h2>我的服务器管理员没有下载链接，我该如何修补apk（安卓）？</h2>
            <p>你可以用 <a href="https://sif2patch.zhushenwudi.top">@arasfon's sif2 apk 修补工具</a>。
                在“服务器URL”中填写"{window.location.origin}"，在“资源URL”中填写 "{assetUrl}"（默认已经帮你填入了以上信息）。
                选择你的游戏版本, 更改头部格式为“Lowercase”, 最后点击开始修补。完成修补后使用 <a
                        href="https://github.com/patrickfav/uber-apk-signer">uber-apk-signer</a> 来签署apk.
                最后便可以安装到你的手机上了！</p>
        </>
    }

    return (
            <div id="home">
                <h1>帮助/关于</h1>
                <h2>“ew”是什么？这个服务器是用来做什么的？</h2>
                <p>“ew”是一个用Rust编写的私人服务器，原作者：Ethan O'Brien，原项目：<a
                        href="https://git.ethanthesleepy.one/ethanaobrien/ew">ew仓库地址</a>。
                    本项目为二次开发版本，用于短命的游戏《Love Live! School idol festival 2 MIRACLE LIVE!》，
                    这是一款以Love Live!为主题的移动节奏游戏。</p>

                <h2>我只是想在这个服务器上玩，我该如何安装这个应用程序？（安卓）</h2>
                <p>{downloadUrl}</p>

                {downloadUrl === defaultDownloadUrl ? renderNoAndroidDownloadUrl() : null}

                <h2>我该如何安装这款应用？（iOS）</h2>
                <p>在iOS上运行要比Android简单得多，这要归功于Discord上的Triangle。你首先要下载一个用于 <a
                        href={downloadUrliOSGL}>国际服</a> 或者 <a href={downloadUrliOSJP}>日服</a> 的ipa文件,
                    然后使用 <a href="https://sideloadly.io/">Sideloadly</a> (或任何能够实现侧载的应用程序)来安装这个APP。打开手机系统设置,
                    导航到SIF2应用的设置页面, 填入“Server URL”："{window.location.origin}" 与 “Assets URL”："{assetUrl}"。
                    如果您在打开应用程序时遇到任何错误，请确保设置中的所有网址都没有以斜杠结尾。</p>

                <h2>求求！我尝试打开SIF2，但它显示为“不可用”（iOS）。</h2>
                <p>不要删除当前的SIF2，只需重新侧载该应用程序。这是苹果的安全功能。</p>

                <h2>程序的执行效率如何？</h2>
                <p>运行得相当不错。服务器本身占用的存储空间甚至不到20兆字节，并且是用Rust编写的。我个人认为它写得相当好。</p>

                <h2>我的电脑/笔记本电脑能运行服务器吗？</h2>
                <p>非常有可能。如果平台是支持 <a
                        href="https://doc.rust-lang.org/nightly/rustc/platform-support.html">Rust语言</a> 的,
                    那么答案是肯定的！在我有时间设置自动操作之前，建议手动编译项目。 <a
                            href="https://git.zhushenwudi.top/zhushenwudi/ew">ew仓库地址</a></p>

                <h2>服务器现在是宕机了吗？我无法连接。</h2>
                <p>假设你刚刚在你使用的服务器上加载了这个页面，那么答案是否定的，否则请联系你的服务器管理员。</p>

                <h2>打歌活动能正常游玩吗？</h2>
                <p>大多数活动会让游戏崩溃，不过这确实是不应该的。明星活动部分已实现。你可以提升自己的排名，并在排名表中与其他玩家竞争，但目前尚未实现奖励功能。</p>

                <h2>我该如何获取活动UR呢？</h2>
                <p>可以通过游戏内兑换码的方式领取活动UR：meow、kode、ganuy</p>

                <h2>当我操作窗口关闭时，为什么游戏会崩溃？</h2>
                <p>这很可能意味着服务器上有某些地方出故障了。如果你是自行托管（服务器），请通过Matrix联系我。否则，联系你的服务器管理员，并让他们报告这个问题。</p>
            </div>
    );
}

export default Help;
